LivestreamsApi

Struct LivestreamsApi 

pub struct LivestreamsApi<'a> { /* private fields */ }
Livestreams API - query live streams and global stats

Implementations

Source

impl<'a> LivestreamsApi<'a>

pub async fn get( &self, broadcaster_user_ids: Option<Vec<u64>>, category_id: Option<u32>, language: Option<&str>, sort: Option<LivestreamSort>, limit: Option<u32>, ) -> Result<Vec<Livestream>>

Get currently live streams

Works with both User Access Tokens and App Access Tokens (no special scope required).

Parameters
  • broadcaster_user_ids: Filter by specific broadcaster IDs (max 50)
  • category_id: Filter by category
  • language: Filter by language code (e.g., “en”)
  • sort: Sort order (defaults to ViewerCount)
  • limit: Number of results (1-100, defaults to 25)
Example
// Get top live streams
let streams = client.livestreams().get(None, None, None, None, None).await?;

// Get specific broadcasters
let streams = client.livestreams().get(
    Some(vec![12345, 67890]),
    None, None, None, None,
).await?;
pub async fn stats(&self) -> Result<LivestreamStats>

Get global livestream statistics

Returns the total number of live streams on Kick. Works with both User Access Tokens and App Access Tokens.

Example
let stats = client.livestreams().stats().await?;
println!("Total live streams: {}", stats.total_count);